@@ -50,12 +50,18 @@
 package com.openexchange.caldav.action;
 
 import java.io.IOException;
+import javax.servlet.http.HttpServletResponse;
+import org.jdom2.Element;
 import com.openexchange.caldav.GroupwareCaldavFactory;
+import com.openexchange.caldav.resources.EventResource;
+import com.openexchange.dav.DAVProtocol;
 import com.openexchange.dav.actions.POSTAction;
 import com.openexchange.webdav.action.WebdavRequest;
 import com.openexchange.webdav.action.WebdavResponse;
+import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
+import com.openexchange.webdav.xml.resources.PropfindResponseMarshaller;
 
 /**
  * {@link CalDAVPOSTAction}
@@ -80,10 +86,10 @@ public class CalDAVPOSTAction extends POSTAction {
 
 	@Override
 	public void perform(WebdavRequest request, WebdavResponse response) throws WebdavProtocolException {
-	    if (super.handle(request, response)) {
+	    if (handle(request, response)) {
 	        return;
 	    }
-		WebdavResource resource = request.getResource();
+        WebdavResource resource = request.getResource();
 		if (null != request.getHeader("content-length")) {
 			resource.setLength(new Long(request.getHeader("content-length")));
 		}
@@ -101,4 +107,43 @@ public class CalDAVPOSTAction extends POSTAction {
 		writeResource(resource, response);
 	}
 
+    @Override
+    protected boolean handle(WebdavRequest request, WebdavResponse response) throws WebdavProtocolException {
+        if ("split".equals(request.getParameter("action"))) {
+            /*
+             * handle special "split" action
+             */
+            EventResource eventResource = requireResource(request, EventResource.class);
+            if (false == eventResource.exists()) {
+                throw DAVProtocol.protocolException(request.getUrl(), HttpServletResponse.SC_NOT_FOUND);
+            }
+            WebdavPath splitComponentUrl = eventResource.split(request.getParameter("rid"), request.getParameter("uid"));
+            if ("return=representation".equals(request.getHeader("Prefer"))) {
+                /*
+                 * render multistatus response upon success, yielding the representation of both resulting components
+                 */
+                WebdavResource updatedResource = factory.resolveResource(request.getUrl());
+                WebdavResource newResource = factory.resolveResource(splitComponentUrl);
+                response.setHeader("ETag", updatedResource.getETag());
+                PropfindResponseMarshaller marshaller = new PropfindResponseMarshaller(request.getURLPrefix(), request.getCharset(), request.isBrief())
+                    .addProperty(DAVProtocol.DAV_NS.getURI(), "getetag")
+                    .addProperty(DAVProtocol.CAL_NS.getURI(), "calendar-data")
+                ;
+                Element multistatusElement = prepareMultistatusElement()
+                    .addContent(marshaller.marshal(updatedResource))
+                    .addContent(marshaller.marshal(newResource))
+                ;
+                sendMultistatusResponse(response, multistatusElement);
+            } else {
+                /*
+                 * return simple response with "Split-Component-URL" header, otherwise
+                 */
+                response.setStatus(HttpServletResponse.SC_CREATED);
+                response.setHeader("Split-Component-URL", splitComponentUrl.toString());
+            }
+            return true;
+        }
+        return super.handle(request, response);
+    }
+
 }
