@@ -49,11 +49,15 @@
 
 package com.openexchange.caldav.mixins;
 
+import java.util.Calendar;
 import java.util.Date;
 import org.jdom2.Namespace;
 import com.openexchange.caldav.CaldavProtocol;
+import com.openexchange.caldav.GroupwareCaldavFactory;
 import com.openexchange.caldav.Tools;
-import com.openexchange.caldav.resources.CalDAVFolderCollection;
+import com.openexchange.chronos.common.CalendarUtils;
+import com.openexchange.exception.OXException;
+import com.openexchange.java.util.TimeZones;
 import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;
 
 
@@ -72,17 +76,62 @@ public class MaxDateTime extends SingleXMLPropertyMixin {
     public static final String PROPERTY_NAME = "max-date-time";
     public static final Namespace NAMESPACE = CaldavProtocol.CAL_NS;
 
-    private final CalDAVFolderCollection<?> collection;
+    private final GroupwareCaldavFactory factory;
 
-    public MaxDateTime(CalDAVFolderCollection<?> collection) {
+    private Date maxDateTime;
+
+    /**
+     * Initializes a new {@link MaxDateTime}.
+     *
+     * @param factory The underlying CalDAV factory
+     */
+    public MaxDateTime(GroupwareCaldavFactory factory) {
         super(NAMESPACE.getURI(), PROPERTY_NAME);
-        this.collection = collection;
+        this.factory = factory;
     }
 
     @Override
     protected String getValue() {
-        Date maxDateTime = collection.getIntervalEnd();
+        Date maxDateTime = getMaxDateTime();
         return null != maxDateTime ? Tools.formatAsUTC(maxDateTime) : null;
     }
 
+    /**
+     * Gets the end time of the configured synchronization timeframe for CalDAV.
+     *
+     * @return The end of the configured synchronization interval
+     */
+    public Date getMaxDateTime() {
+        if (null == maxDateTime) {
+            String value = null;
+            try {
+                value = factory.getConfigValue("com.openexchange.caldav.interval.end", "0");
+            } catch (OXException e) {
+                org.slf4j.LoggerFactory.getLogger(MaxDateTime.class).warn("falling back to '0' as interval end", e);
+                value = "0";
+            }
+            /*
+             * try numerical value
+             */
+            try {
+                int days = Integer.parseInt(value);
+                if (0 >= days) {
+                    return null;
+                }
+                Calendar calendar = CalendarUtils.initCalendar(TimeZones.UTC, null);
+                calendar.add(Calendar.DATE, days);
+                maxDateTime = CalendarUtils.truncateTime(calendar).getTime();
+            } catch (NumberFormatException e) {
+                /*
+                 * no numerical value, fall back to static constants, otherwise
+                 */
+                Calendar calendar = CalendarUtils.initCalendar(TimeZones.UTC, null);
+                calendar.add(Calendar.YEAR, "two_years".equals(value) ? 3 : 2);
+                calendar.set(Calendar.DAY_OF_YEAR, 1);
+                maxDateTime = CalendarUtils.truncateTime(calendar).getTime();
+            }
+        }
+        return maxDateTime;
+    }
+
 }
