@@ -50,7 +50,9 @@
 package com.openexchange.dav.osgi;
 
 import org.osgi.service.http.HttpService;
+import com.openexchange.clientinfo.ClientInfoProvider;
 import com.openexchange.contact.ContactService;
+import com.openexchange.dav.DAVClientInfoProvider;
 import com.openexchange.dav.DAVServlet;
 import com.openexchange.dav.attachments.AttachmentPerformer;
 import com.openexchange.dav.mixins.AddressbookHomeSet;
@@ -62,6 +64,7 @@ import com.openexchange.group.GroupService;
 import com.openexchange.login.Interface;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.resource.ResourceService;
+import com.openexchange.uadetector.UserAgentParser;
 import com.openexchange.user.UserService;
 import com.openexchange.webdav.protocol.helpers.PropertyMixin;
 import com.openexchange.webdav.protocol.osgi.OSGiPropertyMixin;
@@ -78,7 +81,7 @@ public class DAVActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { UserService.class, HttpService.class, ContactService.class, GroupService.class, ResourceService.class };
+        return new Class<?>[] { UserService.class, HttpService.class, ContactService.class, GroupService.class, ResourceService.class, UserAgentParser.class };
     }
 
     @Override
@@ -108,6 +111,10 @@ public class DAVActivator extends HousekeepingActivator {
         registerService(PropertyMixin.class, new PrincipalCollectionSet());
         registerService(PropertyMixin.class, new CalendarHomeSet());
         registerService(PropertyMixin.class, new AddressbookHomeSet());
+        /*
+         * DAV client info
+         */
+        registerService(ClientInfoProvider.class, new DAVClientInfoProvider(getService(UserAgentParser.class)), 0);
         openTrackers();
     }
 
