@@ -57,7 +57,7 @@ import com.openexchange.dav.mixins.CurrentUserPrincipal;
 import com.openexchange.dav.principals.PrincipalFactory;
 import com.openexchange.dav.resources.DAVCollection;
 import com.openexchange.exception.OXException;
-import com.openexchange.folderstorage.DefaultPermission;
+import com.openexchange.folderstorage.BasicPermission;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.Permissions;
 import com.openexchange.group.GroupStorage;
@@ -95,7 +95,7 @@ public class UserPrincipalCollection extends DAVCollection {
     @Override
     public Permission[] getPermissions() {
         return new Permission[] {
-            new DefaultPermission(GroupStorage.GROUP_ZERO_IDENTIFIER, true, Permissions.createPermissionBits(
+            new BasicPermission(GroupStorage.GROUP_ZERO_IDENTIFIER, true, Permissions.createPermissionBits(
                 Permission.READ_FOLDER, Permission.NO_PERMISSIONS, Permission.NO_PERMISSIONS, Permission.NO_PERMISSIONS, false))
         };
     }
